@@ -8,7 +8,7 @@ use Moose::Util::MetaRole ();
 
 { package MooseX::OmniTrigger;
 
-    our $VERSION = '0.03';
+    our $VERSION = '0.04';
 
     Moose::Exporter->setup_import_methods;
 
@@ -548,20 +548,14 @@ use Moose::Util::MetaRole ();
 
     # WHICH SETTERS/CLEARERS TO WRAP?
 
-    # FIRST, WE CAN'T WRAP Instance SETTERS, AS WE HAVE NO GOOD WAY OF KNOWING WHETHER THEY'RE BEING
-    # CALLED FOR SET OR FOR SET-RAW OPS.
+    # WE CAN'T WRAP Instance SETTERS, AS WE HAVE NO GOOD WAY OF KNOWING WHETHER THEY'RE BEING CALLED
+    # FOR SET OR FOR SET-RAW OPS.
 
-    # IDEALLY, TO KEEP OmniTrigger WORKING AS MOOSE IS DEVELOPED AND REFACTORED, WE WANT TO WRAP
-    # "BASIC" SETTERS/CLEARERS -- METHODS IN Moose::Meta::Attribute THAT DO NOTHING MORE THAN
-    # SET/CLEAR THE VALUE THROUGH THE INSTANCE INTERFACE AS DIRECTLY AS POSSIBLE AND THUS AREN'T
-    # LIKELY TO CHANGE. AND WE WANT TO WRAP NO MORE SETTERS/CLEARERS THAN ABSOLUTELY NECESSARY,
-    # WHILE STILL INTERCEPTING EVERY "NORMAL" (AND OMITTING EVERY RAW AND INTERNAL-SPECIAL-PURPOSE)
-    # SET/CLEAR OPERATION.
-
-    # WHAT WE'D LIKE IS FOR MOOSE TO GIVE US A PAIR OF BASIC SETTERS FOR HOOKING (ONE MUTABLE, ONE
-    # IMMUTABLE) THROUGH WHICH *ALL* NON-RAW SET OPS MUST ULTIMATELY PASS (INCLUDING INIT-SET OPS).
-    # IT'D BE SWEET IF THESE SETTERS HANDLED WEAKENING,TOO, WHICH ALWAYS OCCURS IMMEDIATELY AFTER
-    # THE SET OP. (WE'D CONSIDER WEAKENING TO BE PART OF BASIC SETTING.)
+    # IDEALLY, WE WANT TO WRAP "BASIC" SETTERS/CLEARERS -- METHODS IN Moose::Meta::Attribute THAT DO
+    # NOTHING MORE THAN SET/CLEAR THE VALUE THROUGH THE INSTANCE INTERFACE AS DIRECTLY AS POSSIBLE
+    # AND THUS AREN'T LIKELY TO CHANGE. AND WE WANT TO WRAP NO MORE SETTERS/CLEARERS THAN ABSOLUTELY
+    # NECESSARY, WHILE STILL INTERCEPTING EVERY "NORMAL" (AND OMITTING EVERY RAW AND INTERNAL-SPECIAL
+    # -PURPOSE) SET/CLEAR OPERATION.
 
     #===============================================================================================
     # MUTABLE INIT-SETTER: THERE ARE A FEW CHOICES, HERE. IN THE END, ALL ROADS LEAD TO
@@ -596,10 +590,10 @@ use Moose::Util::MetaRole ();
     # SETTING THE VALUE, WHICH MAKES IT NOT THE MOST ATTRACTIVE HOOK (ALTHOUGH IT DOES DO
     # WEAKENING). TO PERFORM THE ACTUAL SET OP, IT CALLS SUPER (IN Class::MOP::Attribute), WHICH IS
     # A BETTER HOOK CANDIDATE, AS IT'S PRETTY MUCH A DIRECT LINE TO THE INSTANCE SETTER -- BUT I
-    # CAN'T THINK OF A GOOD MOOSEY WAY TO HANG A METHOD MODIFIER ON Moose::Meta::Attribute'S
-    # *SUPER'S* set_value WITHOUT CAUSING PROBLEMS. FORTUNATELY, IT LOOKS LIKE set_value IS THE ONLY
-    # (MUTABLE NON-INIT) SETTER IN Attribute, AND IT'S ORGANIZED WITH TRIGGERS IN MIND, ANYWAY, WITH
-    # THE TRIGGER OP BEING CONVENIENTLY THE LAST THING TO HAPPEN. WE CAN WRAP set_value AND FEEL
+    # CAN'T THINK OF A GOOD WAY TO HANG A METHOD MODIFIER ON Moose::Meta::Attribute'S *SUPER'S*
+    # set_value WITHOUT CAUSING PROBLEMS. FORTUNATELY, IT LOOKS LIKE set_value IS THE ONLY (MUTABLE
+    # NON-INIT) SETTER IN Attribute, AND IT'S ORGANIZED WITH TRIGGERS IN MIND, ANYWAY, WITH THE
+    # TRIGGER OP BEING CONVENIENTLY THE LAST THING TO HAPPEN. WE CAN WRAP set_value AND FEEL
     # CAUTIOUSLY OK ABOUT IT.
 
     around [qw(set_value clear_value)] => sub {
@@ -799,7 +793,7 @@ set, or clear operation.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =head1 SYNOPSIS
 
@@ -870,9 +864,7 @@ call stack are quietly prevented.
 
 =head1 CAVEATS
 
-MooseX::OmniTrigger currently relies on Moose::Meta::Class::_call_all_triggers and so requires Moose
-2.02. If you've an interest in using this module but are unable to upgrade to the required Moose,
-please let me know and I'll look into providing some backward compatibility.
+MooseX::OmniTrigger currently requires Moose 2.02. Compatibility with older Mooses is TODO.
 
 =head1 AUTHOR
 
